Error

Enum Error 

#[non_exhaustive]
pub enum Error {
Show 27 variants MissingField(&'static str), ShortRow { field: &'static str, row: usize, expected: usize, got: usize, }, BadFloat { field: &'static str, row: usize, value: String, }, UnbalancedBrackets(&'static str), UnknownBus { bus_id: BusId, element_index: usize, }, ZeroImpedance { row: usize, }, NonFiniteSusceptance { row: usize, }, DimensionMismatch { n: usize, b_len: usize, }, NoGenerators, MissingGenCost { gen_index: usize, }, UnsupportedCostModel { gen_index: usize, model: u8, ncost: usize, }, GenCostCountMismatch { gens: usize, gencost: usize, }, ReferenceBusCount { found: usize, }, InvalidBaseMva { base: f64, }, ShapeMismatch { what: &'static str, expected: usize, got: usize, }, SingularNetwork, UngroundedComponent { components: usize, }, Io(Error), Mtx(String), Parquet(String), EmptyScenarioBatch, ScenarioIdOverflow { base: i64, index: usize, }, NormalizedGridfmSnapshot { scenario: i64, }, NonFiniteGridfmValue { scenario: i64, element: &'static str, row: usize, field: &'static str, value: f64, }, ScenarioShapeMismatch { index: usize, reason: ScenarioMismatch, }, FormatRead { format: &'static str, message: String, }, UnknownFormat(String),
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


MissingField(&'static str)



ShortRow

Fields

field: &'static str
row: usize
expected: usize
got: usize


BadFloat

Fields

field: &'static str
row: usize
value: String


UnbalancedBrackets(&'static str)



UnknownBus

Fields

bus_id: BusId
element_index: usize


ZeroImpedance

Fields

row: usize


NonFiniteSusceptance

Fields

row: usize


DimensionMismatch

Fields

b_len: usize


NoGenerators



MissingGenCost

Fields

gen_index: usize


UnsupportedCostModel

Fields

gen_index: usize
model: u8
ncost: usize


GenCostCountMismatch

Fields

gens: usize
gencost: usize


ReferenceBusCount

Fields

found: usize


InvalidBaseMva

Fields

base: f64


ShapeMismatch

Fields

what: &'static str
expected: usize
got: usize


SingularNetwork



UngroundedComponent

Fields

components: usize


Io(Error)



Mtx(String)



Parquet(String)



EmptyScenarioBatch



ScenarioIdOverflow

Fields

base: i64
index: usize

0-based position of the snapshot whose base + index overflowed.



NormalizedGridfmSnapshot

Fields

scenario: i64


NonFiniteGridfmValue

Fields

scenario: i64
element: &'static str
row: usize
field: &'static str
value: f64


ScenarioShapeMismatch

Fields

index: usize

0-based position of the offending snapshot in the batch (independent of the snapshot’s scenario id).



FormatRead

Fields

format: &'static str
message: String


UnknownFormat(String)

Implementations

Source

impl Error

pub fn category(&self) -> ErrorCategory

Classify this error. The match is exhaustive over the variant set (no wildcard), so adding an Error variant is a compile error here until it is categorized — categorization can’t silently drift as the enum grows.